Why not adopt me?
This distribution is up for adoption!
If you're interested then please contact the PAUSE module admins via
email.
NAME
publisher.pl - reformat iTunes Music Library
SYNOPSIS
% publisher.pl TEMPLATE [ LIBRARY [ PLAYLIST ] ]
DESCRIPTION
This script reformats the iTunes Music Library according to the Text::Template template in TEMPLATE. By default it uses the iTunes Music Library in your home directory, or the file you specify in LIBRARY. It works with all the tracks in the library by default, or the playlist PLAYLIST.
The template has access to these variables:
AUTHOR
brian d foy, <bdfoy@cpan.org>
COPYRIGHT
Copyright 2002, brian d foy, All rights reserved.
You may use this script under the same terms as Perl itself.